@@ -1,5 +1,19 @@
 plotK <- function(K,n=15,L=TRUE,persp=FALSE,legend=TRUE,...)
 {
+devl=dev.list()
+if(is.null(devl))
+{
+old.par <- par(no.readonly = TRUE)    
+on.exit(par(old.par))
+}
+else
+{
+dev.off(devl[length(devl)])
+X11()
+old.par <- par(no.readonly = TRUE)    
+on.exit(par(old.par))
+}
+
   if (isTRUE(L))
     {
       k <- K$Khat-K$Ktheo
@@ -23,7 +37,7 @@ plotK <- function(K,n=15,L=TRUE,persp=FALSE,legend=TRUE,...)
   if (isTRUE(persp))
     {
       mask <- matrix(0,ncol=length(K$times),nrow=length(K$dist))
-      for(i in 1:length(K$dist)){ for(j in 1:length(K$times)){mask[i,j] <- COL[.iplace(x=k[i,j],X=M,xinc=diff(range(M))/(n-1))]}}
+      for(i in 1:length(K$dist)){ for(j in 1:length(K$times)){mask[i,j] <- COL[findInterval(x=k[i,j],vec=M)]}}
       COL <- mask[1:(length(K$dist)-1),1:(length(K$times)-1)]
       
       if(isTRUE(legend))
@@ -33,8 +47,8 @@ plotK <- function(K,n=15,L=TRUE,persp=FALSE,legend=TRUE,...)
           persp(x=K$dist, y=K$times, z=k, xlab="u",ylab="v", zlab="",expand=1, col=COL, ...)
           title(titl,cex.main=2)
           par(fig=c(0.825,1,0,1))
-          mini <- .iplace(x=min(k,na.rm=T),X=M,xinc=diff(range(k))/(n-1))
-          maxi <- .iplace(x=max(k,na.rm=T),X=M,xinc=diff(range(k))/(n-1))
+          mini <- findInterval(x=min(k,na.rm=TRUE),vec=M)
+          maxi <- findInterval(x=max(k,na.rm=TRUE),vec=M)
           legend("right",fill=colo(n)[maxi:mini],legend=M[maxi:mini],horiz=F,bty="n")
         }
       else
@@ -60,8 +74,8 @@ plotK <- function(K,n=15,L=TRUE,persp=FALSE,legend=TRUE,...)
           axis(2,at=at[length(at)],labels="v",cex.axis=2)
           title(titl,cex.main=2)
           par(fig=c(0,1,0.1,1))
-          mini <- .iplace(x=min(k,na.rm=T),X=M,xinc=diff(range(k))/(n-1))
-          maxi <- .iplace(x=max(k,na.rm=T),X=M,xinc=diff(range(k))/(n-1))
+          mini <- findInterval(x=min(k,na.rm=TRUE),vec=M)
+          maxi <- findInterval(x=max(k,na.rm=TRUE),vec=M)
           legend("right",fill=colo(n)[maxi:mini],legend=M[maxi:mini],horiz=F,bty="n")
         }
       else
@@ -78,5 +92,6 @@ plotK <- function(K,n=15,L=TRUE,persp=FALSE,legend=TRUE,...)
           title(titl,cex.main=2)
         }
     }
+par(old.par)
 }
   
